#
# spec file for package WindowMaker
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           WindowMaker
Summary:        A Colorful and Flexible Window Manager
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND SUSE-Public-Domain
Group:          System/GUI/Other
Version:        0.96.0
Release:        1.3
URL:            http://windowmaker.org/
Source:         http://windowmaker.org/pub/source/release/%{name}-%{version}.tar.gz
Source1:        %{name}-extra-0.1.tar.bz2
Source2:        theme.tar.bz2
Source4:        README.SUSE
Source5:        %{name}.desktop
Source6:        windowmaker
Patch1:         %{name}-config.patch
Patch2:         %{name}-menu.patch
Patch3:         fix_wmgenmenu_paths.patch
#
Patch101:       wm-giflib.patch
# PATCH-FEATURE-OPENSUSE
Patch102:       WindowMaker-reproducible.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  libexif-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wallpaper-branding-openSUSE
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xpm)
Requires:       wallpaper-branding-openSUSE
Requires:       xdg-menu
Provides:       windowmanager
Provides:       wmaker

%description
Window Maker is an X11 window manager originally designed to provide
integration support for the GNUstep Desktop Environment. In every way
possible, it reproduces the elegant look and feel of the NEXTSTEP user
interface. It is fast, feature rich, easy to configure, and easy to
use. It is also free software, with contributions being made by
programmers from around the world.

Window Maker has a stable user interface since many years and comes
with a powerful GUI configuration editor called WPrefs, which removes
the need to edit text-based config files by hand. It supports running
dockapps which make everyday tasks such as monitoring system
performance and battery usage, mounting devices or connecting to the
internet very easy. Please see the features section for more specifics
on what Window Maker can do, and how it compares with other popular
window managers.

%package devel
Summary:        Development files for WindowMaker
License:        GPL-2.0-or-later
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}

%description devel
This package contains the header files and libraries necessary for
developing applications which use WindowMaker.

%prep
%setup -q -n %{name}-%{version} -a 1
mkdir menu_orig
cp %{name}/{menu.*,plmenu.*} menu_orig
%patch -P 1
%patch -P 2
%patch -P 3
%patch -P 101
%patch -P 102
cp %{S:4} .
cp %{S:6} .
%if 0%{?suse_version} < 1140
rename no nb po/no.*
%endif
# ---------------------------------------------------------------------------

%build
bash -x ./autogen.sh
export LINGUAS="be bg bs ca cs da de el es et fi fr gl hr hu hy it ja ko ms nl no pl pt ro ru sk sv tr zh_CN zh_TW"
export CFLAGS="$RPM_OPT_FLAGS $(freetype-config --cflags)"
%configure \
  --prefix=/usr \
  --datadir=/usr/share \
  --disable-static \
  --with-pic\
  --sysconfdir=/etc/X11 \
  --enable-xinerama \
  --localedir=/usr/share/locale \
  --with-pixmapdir=/usr/share/%{name}/Pixmaps \
  --with-gnustepdir=/usr/lib/GNUstep

make %{?_smp_mflags}
(cd %{name}-extra-0.1
%configure \
  --prefix=/usr \
  --disable-static \
  --with-pic\
  --with-pixmapdir=/usr/share/%{name}/Pixmaps

make %{?_smp_mflags}
)
# ---------------------------------------------------------------------------

%install
make DESTDIR=$RPM_BUILD_ROOT install
install -m 755 dockit $RPM_BUILD_ROOT/usr/bin/dockit
install -m 755 windowmaker $RPM_BUILD_ROOT/usr/bin/windowmaker
cd %{name}-extra-0.1
make DESTDIR=$RPM_BUILD_ROOT install
tar -xvjf %SOURCE2 -C $RPM_BUILD_ROOT/usr/share/%{name}/Themes/
find $RPM_BUILD_ROOT/usr/share/%{name}/Themes -type f -exec chmod 644 {} \;
find $RPM_BUILD_ROOT/usr/share/%{name}/Themes -type d -exec chmod 755 {} \;
# use default openSUSE wallpaper in SUSE theme
pushd %{buildroot}/usr/share/%{name}/Themes/SUSE.themed/
%if 0%{?sle_version} <= 150500 && 0%{?is_opensuse}
ln -sf /usr/share/wallpapers/openSUSEdefault/contents/images/1600x1200.jpg default.png
%endif
%if 0%{?sle_version} >= 150600 && 0%{?is_opensuse}
ln -sf /usr/share/wallpapers/openSUSEdefault/contents/images/1600x1200.png default.png
%endif
%if 0%{?suse_version} > 1600
ln -sf /usr/share/wallpapers/openSUSEdefault/contents/images/1920x1200.png default.png
%endif
popd
#----------------------------------------------------------------------
# not packaged
rm -f $RPM_BUILD_ROOT/%{_mandir}/{cs,ru,sk}/man1/*
rm -f $RPM_BUILD_ROOT/%{_libdir}/*.la
# install kdm/gdm entry
install -m 0755 -d $RPM_BUILD_ROOT/usr/share/xsessions/
install -m 0644 %SOURCE5 $RPM_BUILD_ROOT/usr/share/xsessions/
%suse_update_desktop_file $RPM_BUILD_ROOT/usr/share/xsessions/%{name}.desktop
cd ..
%find_lang %{name}
%find_lang WINGs %{name}.lang
%find_lang WPrefs %{name}.lang
%find_lang WRaster %{name}.lang
%find_lang wmgenmenu %{name}.lang

# rpmlint
%fdupes -s $RPM_BUILD_ROOT/usr/share/

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%license COPYING COPYING.WTFPL
%doc AUTHORS BUGFORM BUGS ChangeLog FAQ
%doc NEWS README* TODO
%doc menu_orig
%dir /etc/X11/%{name}
%config /etc/X11/%{name}/*
/usr/lib/GNUstep
/usr/bin/*
%{_libdir}/*.so.*
%{_mandir}/man1/*
/usr/share/WINGs
/usr/share/%{name}
/usr/share/xsessions/*
/usr/share/applications/*

%files devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so

%changelog
* Wed Nov 20 2024 chris@computersalat.de
- remove WindowMaker-rpmlintrc
- fix build error with wallpaper-branding-openSUSE
* Mon Nov 18 2024 chris@computersalat.de
- Update to 0.96.0 (August 5th 2023)
  * Screen corners can be assigned an external command to be executed
    when the mouse pointer is entering those areas. In WPrefs, “Hot
    Corner Shortcut Preferences” can be used for configuration or by
    manually adding a “HotCorners” key and value to “YES” in the
    ~/GNUstep/Defaults/WindowMaker file. Hot Corners feature is disabled
    by default. Actions are specified by the “HotCornerActions” and are
    defined as a four entries list (“top left action”, “top right action”,
    “bottom left action”, “bottom right action”). A screen corner area is
    a cube shape defined by the “HotCornerEdge” which is a number of
    pixels from 2 (by default) to 10. To lower the risk of triggering
    that feature accidentally a “HotCornerDelay” key can be used which
    is the time before the action is triggered while the pointer is in
    one of the screen corner. Default value is 250 ms.
  * In WPrefs “Keyboard Shortcut Preferences” tab, three new actions
    can be configured: “Capture a portion of the screen”, “Capture a
    window”, “Capture the entire screen”. The file is saved in
    ~/GNUstep/Library/WindowMaker/Screenshots directory under a filename
    format “screenshot_%%Y-%%m-%%d_at_%%H:%%M:%%S” followed by the extension.
    Which can be png or jpg based on WRaster dependencies.
  * libXRes is now an optional dependency. XRes the resource extension
    for the X protocol is used to find the underlying processes
    (and PIDs) responsible for displaying the windows.
  * Support for _NET_WM_FULLSCREEN_MONITORS hint. That hint allows
    applications that support it to be set as fullscreen on multiple
    heads. It depends on Xinerama extension support.
  * To keep the dock on the primary head in a multi-head setup, set the
    option “KeepDockOnPrimaryHead” in ~/GNUstep/Defaults/WindowMaker to
    “YES” or click “Keep dock on primary head” under the WPrefs “Expert
    User Preferences” tab.
- rebase/rework patches
  * WindowMaker-config.patch
  * WindowMaker-menu.patch
  * fix_wmgenmenu_paths.patch
  * wm-giflib.patch
* Wed May 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N format to eliminate usage of deprecated %%patchN.
* Wed Apr 17 2024 Lubos Kocman <lubos.kocman@suse.com>
- Use png for default wallpaper as SLES, TW, Leap 15.6+ are using png
  * Article https://news.opensuse.org/2024/04/09/common-wallpaper-path/
  * Updated style inside theme.tar.bz and symlinks in spec
* Thu Sep  3 2020 max+suse@dnzm.nl
- Added build requirements which result in broader image support and UTF-8/RTL
  improvements.
* Sat Apr 11 2020 chris@computersalat.de
- Update to 0.95.9
  * SwitchPanel is now more configurable:
    you can configure the switch panel icon size by setting the
    “SwitchPanelIconSize” option to your preferred value in
    ~/GNUstep/Defaults/WindowMaker. The font size used in this panel now is also
    sensible to changes in the system font.
  * New user configuration directory environment variable:
    In previous versions, the GNUstep directory used to store a user’s Window
    Maker configuration files was specified by the GNUSTEP_USER_ROOT environment
    variable, which defaulted to ~/GNUstep. However, this environment variable
    was deprecated in gnustep-make v2. Therefore, it has been replaced by the
    WMAKER_USER_ROOT environment variable.
  * libXmu is now an optional dependency
    If the library is not found, compilation work, the only limitation will
    arise when trying to install the standard colormap on displays which are not
    TrueColor. Please note that if you have the library but not the headers,
    configure will still stop; there is no user option to explicitly disable
    the library use.
- Rebase patches
  * WindowMaker-config.patch
  * WindowMaker-menu.patch
- Rework reproducible patch
  * remove WindowMaker-0.95.8-reproducible.patch
  * add WindowMaker-reproducible.patch
* Wed Dec 20 2017 bwiedemann@suse.com
- Add WindowMaker-0.95.8-reproducible.patch to make build reproducible
* Tue Nov 28 2017 crrodriguez@opensuse.org
- Remove xorg-x11-devel metapackage dependencies, replace it for
  specific pkgconfig() buildrequires or automatically generated
  ones for the -devel package
* Tue Mar 14 2017 chris@computersalat.de
- Update to 0.95.8
  * for changes and news see
    http://repo.or.cz/wmaker-crm.git/blob/HEAD:/NEWS
    http://repo.or.cz/wmaker-crm.git/blob/HEAD:/ChangeLog
- rework/rebase patches
  * WindowMaker-menu.patch
  * wm-giflib.patch
- some spec cleanup
  * rename README.SuSE -> README.SUSE
* Sat Jun 25 2016 chris@computersalat.de
- rebase patches (p0)
  * WindowMaker-config.patch
  * WindowMaker-menu.patch
  * fix_wmgenmenu_paths.patch
  * wm-giflib.patch
* Tue Mar 22 2016 kmroz@suse.com
- Fix build breakace related to giflib < 5.1.
* Tue Mar 22 2016 kmroz@suse.com
- Update to WindowMaker-0.95.7
  - Small modification of wm-giflib.patch.
  - Spec file fixes.
- Removed: WindowMaker-0.96.6.tar.gz
- Added: WindowMaker-0.96.7.tar.gz
* Mon Oct  5 2015 mvetter@suse.com
- bsc#900820: Always use default openSUSE wallpaper for theme 'SUSE'.
* Mon Sep 21 2015 mvetter@suse.com
- bsc#779179: Remove old SuSE wallpapers and add openSUSE ones.
* Tue Jan 27 2015 jengelh@inai.de
- Update wm-giflib.patch to support giflib-5.1
* Thu Nov  6 2014 kmroz@suse.com
- Update to WindowMaker-0.95.6
  - Add: WindowMaker-0.95.6.tar.gz
  - Remove: WindowMaker-0.95.5.tar.gz
  - Update WindowMaker-menu.patch to reflect changed menu.nl in
    0.95.6.
  - Update fix_wmgenmenu_paths.patch as most changes are already
    present in 0.95.6.
  - Update wm-giflib.c to reflect code changes (ie. re-written
    wrlib/gif.c with wrlib/load_gif.c). Not clear if this patch
    is even needed, but keeping it around.
* Fri May 30 2014 jengelh@inai.de
- Edit wm-giflib.patch to support giflib7-5.1 API
* Thu Apr 10 2014 sfalken@opensuse.org
- Added --prefix=/usr and --datadir=/usr/share to %%configure to
  correct paths to better match with other WindowManagers in
  openSUSE
- Updated WindowMaker-menu.patch with corrected paths
- Created patch to fix wmgenmenu to remove hardcodes in source
  Add: fix_wmgenmenu_paths.patch
* Sat Sep 14 2013 chris@computersalat.de
- update to 0.95.5
  * http://repo.or.cz/w/wmaker-crm.git/log/cd5e004127d4088df21bd62c20a9d6c61a27763b
- rebase wm-giflib patch
* Mon Jan 28 2013 chris@computersalat.de
- fix changelog
- rebase config patch
* Fri Jan 18 2013 vcizek@suse.com
- update to 0.95.4
  * There was a major code cleanup related to icons,
  * some changes in WPrefs,
  * the addition of a new "Center" placement strategy,
  * support for _NET_FRAME_EXTENTS,
  * the removal of CPP dependency to process menu files and small
    fixes and improvements all around.
- dropped WindowMaker-81eefca4e.patch (merged upstream)
* Tue Jan  8 2013 crrodriguez@opensuse.org
-  wm-giflib.patch --> fix build with newer giflib
  (stuff must also _always_ include "config.h" as the first file)
* Tue Sep 18 2012 chris@computersalat.de
- fix for bnc#780348
  * added WindowMaker-81eefca4e.patch
  * this patch provides fixes for
    o WMRootMenu
    (SuSE, OPEN_MENU, "| xdg_menu --format WindowMaker --charset UTF-8")
    o More (un)maximize tweaks ("jumping window")
  * http://repo.or.cz/w/wmaker-crm.git/commit/81eefca4ef70414d73048300058e5007f402dd7f
* Wed Jun 27 2012 chris@computersalat.de
- update to 0.95.3.99.1 (upcoming next release)
  * GIT version 81eefca4ef70414d73048300058e5007f402dd7f
  * fix for "jumping Windows" on resize
  * fix for SUSE menu
* Fri May 25 2012 chris@computersalat.de
- update to 0.95.3
  * no up-to-date ChangeLog available
    see http://repo.or.cz/w/wmaker-crm.git/shortlog
- rebase patches
  * config, menu
* Fri Feb 17 2012 chris@computersalat.de
- update to 0.95.2
  * no up-to-date ChangeLog available
    see http://repo.or.cz/w/wmaker-crm.git/shortlog
- rebase patches
  * config, menu
- remove obsolete patches
- rpmlintrc
  * add macro-in-comment
  * remove suse-filelist-forbidden
- add missing libjpeg-devel
* Tue Nov 15 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Fix erroneous trailing backslash
* Wed Aug 31 2011 crrodriguez@opensuse.org
- Fix linking problems with new gnu ld
* Tue Jul 26 2011 andrea.turrini@gmail.com
- fixed typos in description of WindowMaker.spec
* Sun Apr  4 2010 ro@suse.de
- fix build with libpng14
* Mon Mar 30 2009 crrodriguez@suse.de
- remove static libwraster
- remove la files
* Thu Feb 12 2009 nadvornik@suse.cz
- updated to development snapshot
* Wed Feb 11 2009 coolo@suse.de
- ignore error about menu.orig - it's left for documentation
* Mon Oct 13 2008 nadvornik@suse.cz
- fixed composite extension usage [bnc#433808]
* Thu May 22 2008 pgajdos@suse.cz
- fixed "local variable used before set" [bnc#353376]
* Sun Apr 27 2008 ro@suse.de
- remove hermes-devel from buildreq
* Tue Mar 18 2008 nadvornik@suse.cz
- fixed a bug in findBestIcon [bnc#371974]
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
* Wed Jan 23 2008 nadvornik@suse.cz
- fixed declaration of functions in event.c [#355254]
* Sat Mar  3 2007 aj@suse.de
- /usr/share/xsessions is now part of filesystem.
* Mon Oct 23 2006 nadvornik@suse.cz
- reverted previous change [#213889]
- added an offer to update the config files to start script
- documented the possibility of compatibility symlinks
  in README.SuSE
* Mon Oct 16 2006 lnussel@suse.de
- add compatibility symlinks /usr/X11R6/GNUstep and
  /usr/X11R6/share/WindowMaker as those directories are still
  referenced in old config files
* Thu Aug 17 2006 nadvornik@suse.cz
- changed prefix /usr/X11R6 -> /usr
* Tue Mar 14 2006 nadvornik@suse.cz
- fixed the previous change
* Thu Mar  9 2006 anicka@suse.cz
- close file descriptors before exec [#155502]
* Wed Mar  8 2006 anicka@suse.cz
- change default fonts to work with all languages [#154758]
* Tue Jan 31 2006 nadvornik@suse.cz
- fixed invalid usage of snprintf [#117663]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 28 2005 nadvornik@suse.cz
- fixed color reference counting [#119439]
* Fri Oct 14 2005 nadvornik@suse.cz
- fixed another missing return value warning
* Fri Oct  7 2005 mmj@suse.de
- fix wrong printf calls
* Mon Sep 12 2005 nadvornik@suse.cz
- increased MAX_WORKSPACENAME_WIDTH because ru.po
  contains longer strings [#116475]
* Fri Jul 22 2005 nadvornik@suse.cz
- fixed fullscreen in OpenOffice.org presentations [#74375]
- fixed char comparison [#95091]
* Thu Jul 14 2005 nadvornik@suse.cz
- updated to 0.92.0:
  * added support for X Input Methods
  * improved hiding/unhiding animations to be quicker and do
    less icon shuffling
* Thu May 12 2005 nadvornik@suse.cz
- fixed bug in WINGs that caused wmaker crash [#82768]
* Wed Apr  6 2005 nadvornik@suse.cz
- fixed to compile with gcc4
- added gettext-devel to neededforbuild
* Tue Mar 22 2005 nadvornik@suse.cz
- fixed crash with KDE applications on 64bit archs [#74246]
- fixed german translation [#74254]
* Thu Feb 17 2005 nadvornik@suse.cz
- do not strip binaries
* Tue Feb 15 2005 nadvornik@suse.cz
- use the correct exec in desktop file
* Thu Feb 10 2005 adrian@suse.de
- add session desktop file
* Sat Feb  5 2005 meissner@suse.de
- fixed missing getenv prototype, added format attributes
  and fixes found by the attributes.
* Wed Jan 26 2005 nadvornik@suse.cz
- fixed 64bit bug [#50203]
* Mon Jan 17 2005 ro@suse.de
- added c++ to neededforbuild (for libtiff)
* Wed Jan  5 2005 nadvornik@suse.cz
- updated to 0.91.0:
  * NetWM support
  * UTF-8 support included upstream
  * antialiased text support included upstream
* Fri Oct 22 2004 nadvornik@suse.cz
- do not install locale files with codeset [#47262]
* Wed Oct 20 2004 ro@suse.de
- locale rename: no -> nb
* Sat Oct  2 2004 wimer@suse.de
- adding new bgs for 9.2
* Thu Apr 29 2004 nadvornik@suse.cz
- fixed high CPU load on omnipresent windows [#38570]
* Mon Apr 19 2004 nadvornik@suse.cz
- fixed missing return values
* Mon Apr  5 2004 nadvornik@suse.cz
- updated SUSE theme [#30775]
* Tue Mar 30 2004 nadvornik@suse.cz
- more fixed widget sizes in WPrefs [#35915]
* Thu Mar 18 2004 nadvornik@suse.cz
- better handling of utf8 charset
- fixed widget sizes in WPrefs (some localized texts did not fit in) [#35915]
* Thu Mar 11 2004 nadvornik@suse.cz
- better handle invalid multibyte characters [#35247]
- added README.SuSE describing the problem
* Tue Feb  3 2004 nadvornik@suse.cz
- fixed temp file handling [#34078]
- run xdg_menu on startup to cache output
- compile with -fno-strict-aliasing
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Sep 23 2003 nadvornik@suse.cz
- fixed changing background color with wmsetbg [#31567]
* Mon Sep 22 2003 nadvornik@suse.cz
- update old SUSE theme on startup, because images from the old
  theme are no longer present
* Fri Sep 19 2003 nadvornik@suse.cz
- new SuSE theme [#30775]
* Fri Sep 12 2003 nadvornik@suse.cz
- fixed updating WMRootMenu on startup [#29508]
* Wed Sep  3 2003 nadvornik@suse.cz
- fixed workspace cycling problem [#29720]
- fixed broken exit dialog in de_DE locale [#29728]
* Mon Sep  1 2003 nadvornik@suse.cz
- fix SuSE menu location in WMRootMenu on startup
* Wed Aug 27 2003 nadvornik@suse.cz
- fixed focus bug [#29004]
- suse menu is cached
* Mon Aug 25 2003 ro@suse.de
- make sure iconv_menu_files is executable
* Mon Aug 25 2003 nadvornik@suse.cz
- added fix for focus flickering [#27175]
- moved config files to /etc/X11
- use xdg-menu for SuSE menu
* Mon May 26 2003 ro@suse.de
- add pkgconfig files to devel subpackage
- remove not-packaged sk man-pages from buildroot
* Tue May  6 2003 mfabian@suse.de
- another improvment to wsetfont by Gerd Knorr <kraxel@suse.de>:
  make the font size easily configurable when using Xft by
  adding a "--size" option to wsetfont.
* Tue May  6 2003 mfabian@suse.de
- update to current CVS (0.80.2.20030506)
- improve wsetfont to set AntialiasedText=YES/NO depending on
  whether the font setup is for Xft or X11 core fonts (and remove
  useless "WINGsConfiguration.antialiasedText = True;" from
  WindowMaker-useMultiByte-useXft.patch).
- set size for "LargDisplayFont" to 24 pixel in wsetfont when
  using Xft.
- add configure test to distinguish between Xft1 and Xft2
  and remove check for RENDER extension only when Xft2 is
  available.
* Mon May  5 2003 mfabian@suse.de
- WindowMaker-wsetfont.patch: use "-*-" instead of "-xftdummy-"
  in the foundry because the latest version of fontconfig now
  actually uses the foundry and inserting an dummy value doesn't
  work anymore.
- remove "fontconfig fontconfig-devel" from neededforbuild again
  and replace xf86 by x-devel-packages
* Mon Apr 28 2003 mfabian@suse.de
- update to current CVS (0.80.2.20030428)
- improved wsetfont now included upstream
- add "fontconfig fontconfig-devel" to neededforbuild,
  add config-dist.sh to remove this when building for SuSE 8.2.
- add option "--no-fonts" to setstyle when installing the
  SuSE-theme in /usr/X11R6/bin/windowmaker to avoid overwriting
  the font done by wsetfont.
* Wed Apr 23 2003 mfabian@suse.de
- update to current CVS (0.80.2.20030423)
- improve "wsetfont" to make it work on FreeBSD as well
- remove: WindowMaker-nls.patch,
  WindowMaker-plmenu.zh_TW.Big5.patch (included upstream)
- remove Vladimir's WindowMaker-LocMenu.patch, a similar fix
  is now included upstream
* Thu Apr 17 2003 mfabian@suse.de
- disable use of assembler mmx stuff because it makes WindowMaker
  crash immediately. This assembler code was recently introduced
  in CVS, but apparently it doesn't work yet.
* Wed Apr 16 2003 mfabian@suse.de
- update to current CVS (0.80.2.20030415) and adapt patches
- add "freetype2 freetype2-devel expat" to neededforbuild to enable
  Xft.
- WindowMaker-useMultiByte-useXft.patch: enable Xft always
  even when there is no RENDER extension, improve fallback font
  settings, call "wsetfont --sans" in wmaker.inst to get reasonable
  default font settings for Xft.
- WindowMaker-wsetfont.patch: extend to support useful font
  settings for Xft. Also include  Support for CP1251
  (Bulgarian and Belarussian) and ISO 8859-5 (Macedonian,
  Cyrillic Serbian) by Anton Zinoviev <zinoviev@debian.org>
* Wed Mar 12 2003 nadvornik@suse.cz
- fixed bug in opening localized menu [#25144]
* Mon Mar  3 2003 nadvornik@suse.cz
- use GNUSTEP_USER_ROOT in windowmaker script [#24418]
* Fri Dec 20 2002 mfabian@suse.de
- update to 0.80.2
- remove WindowMaker-overflow.patch (included upstream)
- remove obsolete configure option --enable-kanji
- add WindowMaker-fontmatching.patch to improve fontset guessing
- improve wsetfont:
  add fontsets: latin9, turkish, efontuni, gnuuni, generic
  add LargeDisplayFont to the lists of fontsets changed by wsetfont
  improve behaviour of '--auto and --locale' switch by using
  'locale charmap' to find out which fontset is suitable.
- add iconv_menu_files script to generate UTF-8 encoded menu files
- fix syntax error in plmenu.zh_TW.Big5
- patch plmenu.ja the same way the other plmenu.* files
  are patched
* Tue Nov 12 2002 nadvornik@suse.cz
- fixed overflow in RCreateImage()
* Tue Jul  2 2002 nadvornik@suse.cz
- updated to 0.80.1: bugfix release
* Wed Apr 24 2002 nadvornik@suse.cz
- used macro %%{_lib}
* Fri Feb 22 2002 nadvornik@suse.cz
- fixed file permissions
* Fri Feb 22 2002 nadvornik@suse.cz
- replaced /home/mawa with $HOME in german menu
* Thu Feb 21 2002 adrian@suse.de
- add SuSE default theme by Ken
- change behaviour of LMB on background (menu instead of selection)
* Mon Feb 18 2002 nadvornik@suse.cz
- added bugfixes from CVS:
  - fixed crash when setting "Emulate AppIcon" [bug #13380]
  - fixed problem with saving session when shared appicon is enabled
  - fixed focus related problems
  - fixes for multihead systems
* Thu Feb 14 2002 nadvornik@suse.cz
- set MultiByteText to yes in WMGLOBAL
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan  8 2002 nadvornik@suse.cz
- updated to 0.80.0
  - shared appicons between applications of the same class
  - Dock/Clip can steal appicons of applications started by other
    means (main menu, terminal) and attach them
  - many bugs fixed
* Fri Nov 16 2001 nadvornik@suse.cz
- set MultiByteText to yes by default
* Mon Oct  8 2001 nadvornik@suse.cz
- updated to 0.70.0
    libPropList is no longer required
    many bugs fixed
* Sun Sep 16 2001 mfabian@suse.de
- fix wsetfont script for Japanese and Korean
* Thu Jul 26 2001 nadvornik@suse.cz
- update to 0.65.1
* Wed Jun  6 2001 nadvornik@suse.cz
- updated to 0.65.0
- compiled with hermes
* Thu Apr 26 2001 nadvornik@suse.cz
- fixed problems with saving icons
* Tue Apr 24 2001 nadvornik@suse.cz
- fixed segfault in WPrefs
* Thu Apr 19 2001 nadvornik@suse.cz
- fixes for ia64
* Fri Apr  6 2001 nadvornik@suse.cz
- better integration of menus generated by susewm
* Thu Mar 29 2001 nadvornik@suse.cz
- fixed bug in keyboard handling
- used RPM_OPT_FLAGS
* Tue Mar 13 2001 nadvornik@suse.cz
- created devel subpackage
* Mon Feb 26 2001 nadvornik@suse.cz
- update to 0.64.0
* Fri Jan 26 2001 nadvornik@suse.cz
- update to 0.63.1
* Fri Dec 15 2000 nadvornik@suse.cz
- added paths for package icons
* Thu Nov 23 2000 nadvornik@suse.cz
- added Provides: wmaker windowmanager
- removed Requires: wterm
* Wed Nov 15 2000 ro@suse.de
- fixed neededforbuild for libPropList
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Tue Oct 10 2000 nadvornik@suse.cz
- fixed list of doc files
* Mon Oct  2 2000 nadvornik@suse.cz
- fixed start script
- used bzip2
* Mon Aug 14 2000 nadvornik@suse.cz
- fixed bug in shutdown.c
* Fri Aug 11 2000 nadvornik@suse.cz
- fixed bug in menu.c
* Thu Jul 27 2000 nadvornik@suse.cz
- "EXEC SAVE_WORKSPACE" replaced with "SAVE_SESSION" in menu
  (bug #3640)
* Tue May  9 2000 nadvornik@suse.cz
- update to 0.62.1
* Wed May  3 2000 nadvornik@suse.cz
- build with i18n support
* Fri Apr 21 2000 nadvornik@suse.cz
- added BuildRoot
* Mon Apr 10 2000 bk@suse.de
- added suse update config macro
* Wed Mar  1 2000 choeger@suse.de
- added mandir
* Tue Feb 29 2000 choeger@suse.de
- added wterm to requires
* Mon Oct 25 1999 ro@suse.de
- switched to libungif
* Tue Oct 19 1999 choeger@suse.de
- new version, 0.61.1
* Tue Sep 28 1999 choeger@suse.de
- added KDE-Support
* Thu Sep 23 1999 choeger@suse.de
- new version
* Mon Sep 20 1999 ro@suse.de
- added provides windowmanager
* Tue Sep 14 1999 ro@suse.de
- finally removed libproplist-files from filelist
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 19 1999 choeger@suse.de
- removed proplist from source archives and
  using the already present version of SuSE Dist.
* Fri Jul 16 1999 choeger@suse.de
- add script windowmaker
- changed wmaker.inst not to touch .xinitrc
* Tue Jul  6 1999 choeger@suse.de
- added GNOME-Support (--enable-gnome)
* Wed Apr 28 1999 choeger@suse.de
- new version 0.53.0
* Tue Mar 23 1999 choeger@suse.de
- bugfix for spec-file (make clean in the Default-Config-Dir)
* Thu Mar 11 1999 choeger@suse.de
- new version 0.51.1
* Tue Jan 19 1999 choeger@suse.de
- actual version 0.50.2
* Mon Dec 21 1998 choeger@suse.de
- actual version 0.20.3
* Thu Jul  9 1998 ro@suse.de
- removed doc/libproplist/COPYING.LIB (simply doesn't exist)
* Wed Jul  1 1998 maddin@suse.de
- first S.u.S.E. version 0.15.1
- changed configure so it works right for libPropList
- moved documentation
- /usr/X11R6/lib/X11/WindowMaker used as wm's home
- made wrapper script for wmaker, called windowmaker so user's
  files are updated correctly
